import Ember from 'ember';
import { translationMacro as t } from "ember-i18n";

export default Ember.Controller.extend({
	i18n: Ember.inject.service(),
	category:null,
	name: null,
	description: null,
	fileElement:null,
	fileRaw:null,
	isAddingCategory: false,
	isNotSavingCategory: true,
	message:{show:false, text:""},
	observeFile: function (){
		var file=this.get('fileElement');
		if (file!=null) {
			this.set('name', file.name);
		} else {
			this.set('name', '');
		}
	}.observes('fileElement'),
	checkErrors: function (fileRequired){
		var i18n=this.get('i18n');
		var errors=0;
		var errorTexts=[];

		var category=this.get('category');
		var name=this.get('name');
		var description=this.get('description');
		var dataRaw=this.get('fileRaw');

		if (category==null || category.get('id')==null){
			errors++;
			errorTexts.addObject(i18n.t("global.errors.select-field-required", {"field-name":i18n.t("global.category")}));
		}
		if (name==null || name.length<3){
			errors++;
			errorTexts.addObject(i18n.t("global.errors.field-required", {"field-name":i18n.t("global.name")}));
		}
		if (fileRequired && (dataRaw==null || dataRaw=="")){
			errors++;
			errorTexts.addObject(i18n.t("global.errors.field-required", {"field-name":i18n.t("attachment.file")}));
		}
		if (errors>0){
			this.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n*&nbsp;"+errorTexts.join("\n*&nbsp;")
			});
			return true;
		}
		return false;
	},
	observeRaw: function(){
		console.log(this.get('fileRaw'));
	}.observes('fileRaw'),
	actions: {
		setCategory: function (category){
			this.set('category', category);
		}
	}
});
