import Ember from 'ember';
import SimpleTable from 'Dashboard/mixins/simple-table';
import CheckRequiredFields from 'Dashboard/utils/required-fields';
import I18n from 'ember-i18n';

export default Ember.Controller.extend(SimpleTable, {
	blockJump: Ember.inject.controller(),
	cache: Ember.inject.service(),
	i18n: Ember.inject.service(),
	selectWarningPrompt: I18n.translationMacro("block-jump.conditions.select-warning"),
	sortedList: function (){
		var ret=[];
		this.get('list').sort(function (e1, e2){
			var diff=e1.get('level')-e2.get('level');
			return diff
		}).forEach(function (blockSession){
			var level=blockSession.get('level');
			var levelGroup=ret.find(function (e){
				return e.level==level;
			});
			if (levelGroup===undefined){
				levelGroup = {
					level: level,
					list: [blockSession]
				};
				ret.push(levelGroup);
			} else {
				levelGroup.list.push(blockSession)
			}
		});
		return ret;
	}.property('list', 'list.@each.level'),
	checkData: function (condition){
		var i18n=this.get('i18n');
		var errors=CheckRequiredFields(i18n, condition, {
			"level_edit":i18n.t("block-jump.conditions.level"),
			"nextLevel":i18n.t("block-jump.conditions.next-level")
		}, 1);
		if (errors.length>0){
			condition.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n"+errors.join("\n"),
				type: "error",
				timer: null
			});
		} else {
			condition.set('level', condition.get('level_edit'));
			condition.set('motivation', condition.get('motivation_edit'));
			condition.set('warning', condition.get('warning_edit'));
			return condition.save();
		}
	},
	actions: {
		add: function (){
			var list=this.get('list');
			var condition=this.store.createRecord('block-jump-condition', {blockJump: this.get('blockJump.model'), level: -1});
			list.insertAt(0, condition);
			this.send('edit', condition);
		},
		editCondition: function (condition){
			condition.set('level_edit', condition.get('level'));
			condition.set('motivation_edit', condition.get('motivation'));
			condition.set('warning_edit', condition.get('warning'));
			this.send('edit', condition);
		}
	}
});
