import Ember from 'ember';
import SimpleTable from 'Dashboard/mixins/simple-table';
import CheckRequiredFields from 'Dashboard/utils/required-fields';
import I18n from 'ember-i18n';

export default Ember.Controller.extend(SimpleTable, {
	blockJump: Ember.inject.controller(),
	cache: Ember.inject.service(),
	selectWarningPrompt: I18n.translationMacro("block-jump.defaults.select-warning"),
	sortedList: function (){
		var ret=this.get('list').sort(function (e1, e2){
			var diff=e1.get('level')-e2.get('level');
			return diff
		});
		return ret;
	}.property('list', 'list.@each.level'),
	checkData: function (defaultJump){
		var i18n=this.get('i18n');
		var errors=CheckRequiredFields(i18n, defaultJump, {
			"level_edit":i18n.t("block-jump.default-jumps.level"),
			"nextLevel":i18n.t("block-jump.default-jumps.next-level")
		}, 1);
		if (errors.length>0){
			defaultJump.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n"+errors.join("\n"),
				type: "error",
				timer: null
			});
		} else {
			defaultJump.set('level', defaultJump.get('level_edit'));
			defaultJump.set('motivation', defaultJump.get('motivation_edit'));
			defaultJump.set('warning', defaultJump.get('warning_edit'));
			return defaultJump.save();
		}
	},
	actions: {
		add: function (){
			var list=this.get('list');
			var defaultJump=this.store.createRecord('block-jump-default', {blockJump: this.get('blockJump.model'), level: -1});
			list.insertAt(0, defaultJump);
			this.send('edit', defaultJump);
		},
		editDefault: function (defaultJump){
			defaultJump.set('level_edit', defaultJump.get('level'));
			defaultJump.set('warning_edit', defaultJump.get('warning'));
			this.send('edit', defaultJump);
		}
	}
});
