import Ember from 'ember';
import SimpleTable from 'Dashboard/mixins/simple-table'

export default Ember.Controller.extend({
	block : Ember.inject.controller(),
	sortedList: function (){
		var ret=[];
		this.get('list').sort(function (e1, e2){
			var diff=e1.get('level')-e2.get('level');
			if (diff==0){
				diff=e1.get('order')-e2.get('order');
			}
			return diff
		}).forEach(function (blockSession){
			var level=blockSession.get('level');
			var levelGroup=ret.find(function (e){
				return e.level==level;
			});
			if (levelGroup===undefined){
				levelGroup = {
					level: level,
					list: [blockSession]
				};
				ret.push(levelGroup);
			} else {
				levelGroup.list.push(blockSession)
			}
		});
		return ret;
	}.property('list', 'list.@each.level'),
	checkData: function (blockSession){
		var i18n=this.get('i18n');
		var level = blockSession.get('level_edit');
		var order = blockSession.get('order');
		var session = blockSession.get('session_edit');
		var errors = [];
		if (level === undefined || level === null || level<0){
			errors.push(i18n.t('global.errors.field-required', {"field-name": i18n.t('block-session.list.level')}));
		}
		if (order === undefined || level === null){
			errors.push(i18n.t('global.errors.field-required', {"field-name": i18n.t('block-session.list.order')}));
		}
		if (session === undefined || session === null){
			errors.push(i18n.t('global.errors.select-field-required', {"field-name": i18n.t('block-session.list.session')}));
		}
		if (errors.length>0){
			blockSession.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n"+errors.join("\n"),
				type: "error",
				timer: null
			});
		} else {
			blockSession.set('level', level);
			blockSession.set('session', session);
			return blockSession.save();
		}
	},
	actions : {
		add: function (){
			var list=this.get('list');
			var blockSession=this.store.createRecord('block-session', {block:this.get('block.model'), level:-1});
			list.insertAt(0, blockSession);
			this.send('edit', blockSession)
		},
		editSession: function (blockSession){
			blockSession.set('session_edit', blockSession.get('session'));
			blockSession.set('level_edit', blockSession.get('level'));
			this.send('edit', blockSession);
		}
	}
}, SimpleTable);
