import Ember from 'ember';
import SimpleTable from 'Dashboard/mixins/simple-table';
import loadAll from 'Dashboard/utils/load-all-pages';
import I18n from 'ember-i18n';

export default Ember.Controller.extend({
	pattern: Ember.inject.controller(),
	selectListBlockPrompt: I18n.translationMacro("block-jump.list.select-block-jump"),
	listBlockJump: function (){
		return loadAll(this.store, "block-jump", 10, {});
	}.property(),
	sortedList: function (){
		return this.get('list').sort(function (e1, e2){
			return e1.get('order')-e2.get('order');
		});
	}.property('list.@each.order'),
	checkData: function (block){
		var i18n=this.get('i18n');
		var name=block.get('name');
		var order=block.get('order');
		var blockJump= block.get('blockJump_edit');
		var errors=[];
		if ( name === undefined || name === null || name.length<3){
			errors.push(i18n.t('global.errors.field-required', {"field-name": i18n.t('global.name')}));
		}
		if ( order === undefined || order === null ){
			errors.push(i18n.t('global.errors.field-required', {"field-name": i18n.t('block.list.order')}));
		}
		if ( blockJump === undefined || blockJump === null){
			errors.push(i18n.t('global.errors.select-field-required', {"field-name": i18n.t('block.list.block-jump')}));
		}
		if (errors.length>0){
			block.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n"+errors.join("\n"),
				type: "error",
				timer: null
			});
		} else {
			block.set('blockJump', blockJump);
			return block.save();
		}
		return null;
	},
	actions: {
		add: function (){
			var list=this.get('list');
			var block=this.store.createRecord('block', {pattern:this.get('pattern.model')});
			list.insertAt(0, block);
			this.send('edit', block);
		},
		editBlock: function (block){
			block.set('blockJump_edit', block.get('blockJump'));
			this.send('edit', block);
		}
	}

}, SimpleTable);
