import Ember from 'ember';
import Utils from 'Dashboard/utils/utils'
import I18n from 'ember-i18n';
import { translationMacro as t } from "ember-i18n";

export default Ember.Controller.extend({
	needs:["student", 'user_session'],
	session: Ember.computed.alias('controllers.user_session.session'),
	i18n: Ember.inject.service(),
	hasTemplateRead: function (){
		return Utils.hasRead(this.get('session'), 'comment_template');
	}.property('session'),
	previous: Ember.computed.alias('model.previous'),
	showCommentComplete: function (){
		var show=localStorage.showCommentComplete;
		if (show===undefined || show===null){
			return true;
		} else {
			return show==="true";
		}
	}.property(),
	observeShowCommentComplete: function (){
		localStorage.showCommentComplete=this.get('showCommentComplete');
	}.observes('showCommentComplete'),
	message: {show:false, type:"info", timer:null, text:""},
	saveMessageOk: function (){
		return {show:true, type:"info", timer:10, text:this.get('i18n').t('global.messages.save-ok')};
	},
	saveMessageError: function (error){
		return {show:true, type:"error", timer:null, text:error};
	},

	email:function (){
		return this.get('controllers.student.model').get('email');
	}.property('controllers.student.model.email'),
	object: function (){
		var model=this.get('model');
		if (model==undefined){
			return null;
		} else if (model.content==undefined){
			return model;
		} else {
			return model.content;
		}
	}.property('model', 'model.content'),
	actions: {
		discardChanges: function (){
			this.get('object').rollback();
		},
		saveChanges: function (){
			var save=this.get('object').save();
			var _this=this;
			save.then(function (){
				_this.set('message', _this.saveMessageOk());
			});
		},
		saveChangesWithEmail: function (){
			var email=this.get('email');
			var i18n=this.get('i18n');
			if (email!=null && email.length>3) {
				if (confirm(i18n.t('comment.confirm.send-email'))) {
					this.get('object').set('email', email);
					var promise = this.get('object').save();
					var _this = this;
					promise.then(function (e) {
						var message= _this.saveMessageOk();
						message.text=i18n.t("comment.messages.save-and-send-ok");
						_this.set('message',message);
						_this.get('object').set('email', '');
					});
					return promise;
				}
			} else {
				//alert(i18n.t('comment.errors.e-mail-required'));
				this.set('message', this.saveMessageError(i18n.t('comment.errors.e-mail-required')));
			}
		}
	}
});
