import PageController from 'Dashboard/controllers/page';

export default PageController.extend({
	queryParams: ['school', 'group'],
	school: null,
	group: null,
	pageSize: 20,
	listPageSize: [20, 60, 100],
	sort: ['lastName', 'firstName'],

	nearPagesList: function (){
		return this.listNearPages(5);
	}.property('page', 'numPages'),

	sortByFirstName: function (){
		var sort=this.get('sort');
		return sort[0]=='firstName'
	}.property('sort'),

	sortByLastName: function (){
		var sort=this.get('sort');
		return sort[0]=='lastName'
	}.property('sort'),

	groupInstance: function (){
		var group=this.get('group');
		if (group!=null){
			return this.store.findRecord('group', group);
		}
		return null;
	}.property('group'),
	schoolInstance: function (){
		var school=this.get('school');
		var groupInstance=this.get('groupInstance');
		if (groupInstance!=null){
			return groupInstance.get('school');
		} else if (school!=null){
			return this.store.query('school', school);
		}

	}.property('groupInstance.school', 'school'),

	pagedList: function (){
		var pageSize=this.get('pageSize');
		var offset=this.get('page')*pageSize;
		var sort=this.get('sort');
		return this.get('model').sortBy(sort[0], sort[1]).slice(offset, offset+pageSize);
	}.property('model.content', 'page', 'pageSize', 'sort'),

	actions:{
		sortBy: function (sort){
			this.set('sort', sort.split(','));
		},
		markAll: function (status){
			this.get('pagedList').forEach(function (student){
				student.set('createPattern', status);
			})
		},
		nextPage: function(){
			this.transitionToRoute('multiple-pattern-config',this.getTransitionQueryParams(1))
		},
		prevPage: function(){
			this.transitionToRoute('multiple-pattern-config',this.getTransitionQueryParams(-1))
		},
		create: function (config){
			var listStudents=this.get('pagedList');
			listStudents.forEach(function (student){
				var createPattern = student.get('createPattern');
				if (createPattern){
					student.set('patternCreateError', false);
					student.set('patternCreated', true);
					var newPattern=this.store.createRecord('older-pattern-relation', {
						older: student,
						pattern: config.get('pattern'),
						workingDays: config.get('workingDays'),
						numberSessions: config.get('numberSessions'),
						maxSessionsWeek: config.get('maxSessionsWeek'),
						block: config.get('block'),
						level: config.get('level'),
						session: config.get('session')
					});
					var promise=newPattern.save();
					promise.then(function (){
						student.set('patternCreated', true);
						student.set('createSession', false);
					}, function (){
						student.set('patternCreateError', true);
					});
				}
			}.bind(this));
		},
		discard: function (){
			this.transitionToRoute('students', {queryParams: {school:this.get('school'), group:this.get('group')}})
		}
	}
});
