import PageController from 'Dashboard/controllers/page';

export default PageController.extend({
	queryParams: ['school', 'group'],
	school: null,
	group: null,
	pageSize: 20,
	listPageSize: [20, 60, 100],
	sort: ['lastName', 'firstName'],

	nearPagesList: function (){
		return this.listNearPages(5);
	}.property('page', 'numPages'),

	sortByFirstName: function (){
		var sort=this.get('sort');
		return sort[0]=='firstName'
	}.property('sort'),

	sortByLastName: function (){
		var sort=this.get('sort');
		return sort[0]=='lastName'
	}.property('sort'),

	groupInstance: function (){
		var group=this.get('group');
		if (group!=null){
			return this.store.findRecord('group', group);
		}
		return null;
	}.property('group'),
	schoolInstance: function (){
		var school=this.get('school');
		var groupInstance=this.get('groupInstance');
		if (groupInstance!=null){
			return groupInstance.get('school');
		} else if (school!=null){
			return this.store.query('school', school);
		}

	}.property('groupInstance.school', 'school'),

	pagedList: function (){
		var pageSize=this.get('pageSize');
		var offset=this.get('page')*pageSize;
		var sort=this.get('sort');
		return this.get('model').sortBy(sort[0], sort[1]).slice(offset, offset+pageSize);
	}.property('model.content', 'page', 'pageSize', 'sort'),

	actions:{
		sortBy: function (sort){
			this.set('sort', sort.split(','));
		},
		markAll: function (status){
			this.get('pagedList').forEach(function (student){
				student.set('createSession', status);
			})
		},
		addSession: function (modelSession, dayToCreate){
			if (modelSession!=null){
				var _this=this;
				var listStudents=this.get('pagedList');
				listStudents.forEach(function (student){
					var createSession=student.get('createSession');
					if (createSession){
						student.set('sessionCreateError', false);
						student.set('sessionCreated', true);
						var newSession=_this.store.createRecord('session', {
							publish_date:dayToCreate,
							model_based: modelSession,
							student:student
						});
						var promise=newSession.save();
						promise.then(function (){
							student.set('sessionCreated', true);
							student.set('createSession', false);
						}, function (){
							student.set('sessionCreateError', true);
						});
					}
				});
			} else {
				alert(Ember.I18n.t('student.errors.not-selected-model'));
			}
		},
		nextPage: function(){
			this.transitionToRoute('multiple-session-add',this.getTransitionQueryParams(1))
		},
		prevPage: function(){
			this.transitionToRoute('multiple-session-add',this.getTransitionQueryParams(-1))
		}
	}
});
