import Ember from 'ember';
import Utils from '../utils/utils';

export default Ember.Controller.extend({
	needs: ['user_session'],
	session: Ember.computed.alias("controllers.user_session"),
	i18n: Ember.inject.service(),

	// Load cache data required
	init: function (){
		this.store.queryRecord('percentile',{});
	},


	enabledNavigation:function (){
		var navigation=[];
		var session=this.get('session.session');
		var i18n=this.get('i18n');
		if (Utils.hasRead(session, 'session')){
			navigation.addObject({
				name:i18n.t("navigation.children.title"),
				options: [
					{name: i18n.t("navigation.children.summary"), link: "navigation.index"},
					{name: i18n.t("navigation.children.schools"), link: "schools"},
					{name: i18n.t("navigation.children.students"), link: "students"}
				]
			});
		}
		var hasModelSession=Utils.hasWrite(session, 'model_session');
		if (hasModelSession){
			var Development={
				name: i18n.t("navigation.development.title"),
				options:[]
			};
			if (hasModelSession){
				Development.options.addObject({name: i18n.t("navigation.development.models-session"), link:'session-models'});
			}
			navigation.addObject(Development);
		}

		var hasAttachment=Utils.hasWrite(session,'attachment');
		var hasPercentile=Utils.hasWrite(session, 'percentile');
		var hasCommentTemplate=Utils.hasWrite(session, 'comment_template');
		if ( hasAttachment|| hasPercentile || hasCommentTemplate){
			var Maintenance={
				name: i18n.t("navigation.maintenance.title"),
				options:[]
			};
			if (hasPercentile){
				Maintenance.options.addObject({name: i18n.t("navigation.maintenance.percentiles"), link:"percentiles"});
			}
			if (hasAttachment){
				Maintenance.options.addObject({name: i18n.t("navigation.maintenance.attachments"), link:"attachments"});
			}
			if (hasCommentTemplate){
				Maintenance.options.addObject({name:i18n.t("navigation.maintenance.comment-templates"), link:'comment-templates'});
			}
			navigation.addObject(Maintenance);
		}
		if (Utils.hasWrite(session, 'automatic_pattern')){
			navigation.addObject({
				name: i18n.t("navigation.automatic-pattern.title"),
				options: [
					{
						name: i18n.t("navigation.automatic-pattern.warnings"),
						link:"warnings"
					}, {
						name: i18n.t("navigation.automatic-pattern.working-days"),
						link: "working-days"
					}, {
						name: i18n.t("navigation.automatic-pattern.patterns"),
						link: "patterns"
					}, {
						name: i18n.t("navigation.automatic-pattern.block-jumps"),
						link: "block-jumps"
					}
				]
			});
		}
		if (Utils.hasWrite(session,'administration')){
			navigation.addObject({
				name:i18n.t("navigation.administration.title"),
				options: [
					{name:i18n.t("navigation.administration.users"), link:"users"}
				]
			});
		}
		return navigation;
	}.property('session.session', 'i18n.locale'),
	actions: {
		logout: function() {
			this.get('session').loggout();
			this.transitionToRoute('/login');
		},
		renew: function (){
			this.get('session').renewSession();
		}
	}
});
