import Ember from 'ember';

export default Ember.Controller.extend({
	queryParams:["page", "pageSize", "search", 'order'],

	page:0,
	pageSize:10,
	listPageSize:[10,25,50],
	search: "",
	order: null,
	//totalItems: Ember.computed.oneWay('model.meta.total'),
	totalItems: Ember.computed.alias('model.meta.total'),

	isFirst: function (){
		return this.page==0;
	}.property("page"),

	numPages: function (){
		var pageSize=this.get('pageSize');
		var totalItems=this.get('totalItems');
		var remainder=totalItems%pageSize;
		var pages=(totalItems-remainder)/pageSize;
		if (remainder){
			pages++;
		}
		return pages
	}.property('totalItems', 'pageSize'),
	lastPage: function (){
		return this.get('numPages')-1;
	}.property("numPages"),

	isLast: function (){
		//var modelType = this.get('model.type');
		//var total=this.get('totalItems');
		var numPages=this.get('numPages');
		var page=this.get('page');
		return page+1>=numPages;
	}.property("page", "numPages"),

	listNearPages: function (near){
		var page=this.get('page');
		var numPages=this.get('numPages');

		var first=page-near;
		var last=page+near+1;
		if (first<0){
			first=0;
		}
		if (last>numPages){
			last=numPages;
		}
		var ret=[];
		for (var i=first; i<last; i++){
			var p={label: i+1, id:i, current: i==page};
			ret.addObject(p)
		}
		return ret;
	},

	getTransitionQueryParams: function (delta) {
		return {queryParams: {page: this.page + delta}}
	},

	actions:{
		nextPage: function(){
			this.set('page', this.get('page')+1);
		},
		prevPage: function(){
			this.set('page', this.get('page')-1);
		},
		goToPage: function (page){
			this.set('page', page);
		},
		searchAction: function (){
			this.set('page', 0);
			this.set('search',this.get('searchText'));
		},
		sort: function (sort_fields){
			this.set("order", sort_fields.split(','));
		}
	}
});
