import Ember from 'ember';
import I18n from 'ember-i18n';
import Utils from 'Dashboard/utils/utils';
import CheckSelectedFields from 'Dashboard/utils/required-select-fields';
import CheckFields from 'Dashboard/utils/required-fields';

export default Ember.Controller.extend({
	i18n:Ember.inject.service(),
	cache: Ember.inject.service(),
	selectPatternPrompt: I18n.translationMacro('pattern-config.form.select-pattern-prompt'),
	selectBlockPrompt: I18n.translationMacro('pattern-config.form.select-block-prompt'),
	selectLevelPrompt: I18n.translationMacro('pattern-config.form.select-level-prompt'),
	selectSessionPrompt: I18n.translationMacro('pattern-config.form.select-session-prompt'),
	selectDaysWorkPrompt: I18n.translationMacro('pattern-config.form.select-working-days-prompt'),
	userSession : Ember.inject.controller(),

	hasSessionWrite: function (){
		var session=this.get('userSession.session');
		return Utils.hasWrite(session, 'session');
	}.property('userSession'),
	hasNotSessionWrite: function (){
		return ! this.get('hasSessionWrite');
	}.property('hasSessionWrite'),

	enabledBlockSelect: function (){
		var permission=this.get('hasSessionWrite');
		return this.get('model.pattern.id') && permission
	}.property('model.pattern.id',"hasSessionWrite"),
	enabledLevelSelect: function (){
		var permission=this.get('hasSessionWrite');
		return this.get('model.block_edit.id') && permission
	}.property('model.block_edit.id', "hasSessionWrite"),
	enabledSessionSelect: function (){
		var permission=this.get('hasSessionWrite');
		return this.get('model.level_edit') && permission
	}.property('model.level_edit', "hasSessionWrite"),

	listBlocks: function (){
		return this.get('model.pattern.blocks');
	}.property('model.pattern'),
	listLevels: function (){
		var sessions=this.get('model.block_edit.sessions');
		if (sessions!==null && sessions!==undefined) {
			var levels = [];
			sessions.forEach(function (s) {
				var level = s.get('level');
				if (!levels.contains(level)) {
					levels.push(level);
				}
			});
			return levels.map(function (e) {
				return Utils.createElement(e, e);
			});
		} else {
			return [];
		}
	}.property('model.block_edit.sessions.@each.level'),
	listSessions: function (){
		var sessions=this.get('model.block_edit.sessions');
		if (sessions!==null && sessions!==undefined) {
			var level = this.get('model.level_edit.id');
			return sessions.sortBy('order').filter(function (e) {
				return e.get('level') === level;
			});
		} else {
			return [];
		}
	}.property('model.block_edit.sessions.@each.session.name', 'model.level_edit'),
	message: {
		show:false,
		type:"error",
		timer: null,
		text:""
	},
	listWarnings: function (){
		return this.get('model').get('warnings').slice(0);
	}.property('model.warnings'),
	checkData: function (config){
		var i18n=this.get('i18n');
		var errors=CheckSelectedFields(i18n, config, {
			"pattern":i18n.t("pattern-config.form.pattern"),
			"block_edit":i18n.t("pattern-config.form.block"),
			"level_edit":i18n.t("pattern-config.form.level"),
			"session":i18n.t("pattern-config.form.session"),
			"workingDays":i18n.t("pattern-config.form.working-days")
		});
		errors.addObjects(CheckFields(i18n, config, {
			"numberSessions": i18n.t("pattern-config.form.number-sessions")
		}));
		if(errors.length>0){
			this.set('message', {
				show:true,
				type:"error",
				text: i18n.t('global.errors.check-and-solve')+":\n"+errors.join("\n"),
				timer: null
			});
		} else {
			this.set('message', {
				show:false,
				type:"error",
				text: "",
				timer: null
			});
			if (config.get('level')!==config.get('level_edit').id ||
				config.get('block')!==config.get('block_edit')){
				config.set('level', config.get('level_edit').id);
				config.set('block', config.get('block_edit'));
				config.set('lastBlock', null);
				config.set('lastLevel', null);
			}
			var warnings = this.get('listWarnings');
			var model_warnings=config.get('warnings');
			model_warnings.clear();
			warnings.forEach(function (w){
				model_warnings.pushObject(w);
			});
			return config;
		}
	},
	actions:{
		removeWarning: function (warning){
			this.get('listWarnings').removeObject(warning)
		}
	}
});
