import PageController from 'Dashboard/controllers/page';
import Ember from 'ember';
import I18n from 'ember-i18n';
import SimpleTable from 'Dashboard/mixins/simple-table';

export default PageController.extend(SimpleTable, {
	selectLanguagePrompt: I18n.translationMacro("global.lang.select"),
	nearPagesList: function (){
		return this.listNearPages(5);
	}.property('page', 'numPages'),
	checkData: function (pattern){
		var i18n=this.get('i18n');
		var name=pattern.get('name');
		var language=pattern.get('language_edit');
		var errors=[];
		if ( name === undefined || name === null || name.length<3){
			errors.push(i18n.t('global.errors.field-required', {"field-name": i18n.t('global.name')}));
		}
		if ( language === undefined || language === null || language.get('id') === undefined){
			errors.push(i18n.t('global.errors.select-field-required', {"field-name": i18n.t('pattern.list.language')}));
		}
		if (errors.length>0){
			pattern.set('message', {
				show:true,
				text: i18n.t('global.errors.check-and-solve')+"\n"+errors.join("\n"),
				type: "error",
				timer: null
			});
		} else {
			pattern.set('language', language);
			return pattern.save();
		}
		return null;
	},
	actions: {
		add: function (){
			var list=this.get('list');
			var pattern=this.store.createRecord('pattern', {});
			list.insertAt(0, pattern);
			this.send('edit', pattern);
		},
		editPattern: function (pattern){
			pattern.set('language_edit', pattern.get('language'));
			this.send('edit', pattern);
		}
	}
});
