import Ember from 'ember';

export default Ember.Controller.extend({
	needs:['student'],
	student: Ember.computed.alias('controllers.student.model'),
	school: Ember.computed.alias('student.group.school'),
	hasStudentReadOnly: Ember.computed.alias('controllers.student.hasStudentReadOnly'),
	list_users: function (){
		var school=this.get('school');
		var user_manager=this.get('model');
		if (school!=null && school.get('id')!=null){
			var promise=this.store.query('user',{school:school.get('id')});
			var _this=this;
			promise.then(function (d){
				d.forEach(function (user){
					user.set('is_managed', user_manager.contains(user));
				});
			});
			return promise;
		} else {
			return [];
		}
	}.property('school.id'),
	sort_list_users: function (){
		var list=this.get('list_users.content');
		if (list!=undefined) {
			var searchText = this.get('searchText');
			if (searchText.length>2){
				list=list.filter(function (u){
					return u.get('name').indexOf(searchText) >= 0;
				});
			}
			return list.sortBy('name');
		}
		return [];
	}.property('list_users.content', 'searchText'),
	page:0,
	pageSize: 10,
	searchText: "",

	totalItems: function (){
		var list= this.get('sort_list_users');
		if (list!=null){
			return list.length
		}
		return 0;

	}.property('sort_list_users.content'),

	isFirst: function (){
		return this.page==0;
	}.property("page"),

	numPages: function (){
		var pageSize=this.get('pageSize');
		var totalItems=this.get('totalItems');
		var remainder=totalItems%pageSize;
		var pages=(totalItems-remainder)/pageSize;
		if (remainder){
			pages++;
		}
		return pages
	}.property('totalItems', 'pageSize'),
	lastPage: function (){
		return this.get('numPages')-1;
	}.property("numPages"),

	isLast: function (){
		//var modelType = this.get('model.type');
		//var total=this.get('totalItems');
		var numPages=this.get('numPages');
		var page=this.get('page');
		return page+1>=numPages;
	}.property("page", "numPages"),

	listNearPages: function (near){
		var page=this.get('page');
		var numPages=this.get('numPages');

		var first=page-near;
		var last=page+near+1;
		if (first<0){
			first=0;
		}
		if (last>numPages){
			last=numPages;
		}
		var ret=[];
		for (var i=first; i<last; i++){
			var p={label: i+1, id:i, current: i==page};
			ret.addObject(p)
		}
		return ret;
	},

	listPageSize: [10,20],

	nearPagesList: function (){
		return this.listNearPages(5);
	}.property('page', 'numPages'),

	pagedList: function (){
		var pageSize=this.get('pageSize');
		var offset=this.get('page')*pageSize;
		var list=this.get('sort_list_users');
		if (list!=null){
			return list.slice(offset, offset+pageSize);
		} else {
			return [];
		}
	}.property('sort_list_users', 'page', 'pageSize'),

	actions: {
		nextPage: function(){
			this.set('page', this.get('page')+1);
		},
		prevPage: function(){
			this.set('page', this.get('page')-1);
		},
		goToPage: function (page){
			this.set('page', page);
		},
		save: function (){
			var selected=this.get('list_users').filter(function (e){
				return e.get('is_managed');
			});
			var model=this.get('model');
			model.clear();
			model.addObjects(selected);

		}
	}
});
