import Ember from 'ember';
import PageController from './page'
import Utils from '../utils/utils'
import I18n from 'ember-i18n'

export default PageController.extend({
	needs: ["student", "session", "user_session", "session/Add", "student"],
	queryParams: ["filterModels"],
	i18n: Ember.inject.service(),
	student: Ember.computed.alias('controllers.student.model'),
	sub_session_model: Ember.computed.alias('controllers.session.model'),
	session: Ember.computed.alias("controllers.user_session.session"),
	studentGroup: Ember.computed.alias("controllers.student.model.group"),
	showingFilter: false,

	searchModel: "",
	filterModels: [],
	filterModelsObjects: function () {
		var listModels = this.get("listModels");
		if (listModels.isFulfilled) {
			return this.get("filterModels").map(function (id) {
				return listModels.find(function (model) {
					return model.id == id
				});
			})
		} else {
			return [];
		}
	}.property('filterModels', 'listModels.content'),
	listModels: function () {
		return this.store.query('session-model', {enabled: true, student: this.get('controllers.student.id')})
	}.property('studentGroup.school.id'),
	filteredListModels: function () {
		var searchModel = this.get('searchModel').toUpperCase();
		var filterModels = this.get('filterModels');
		var listModels = this.get('listModels').filter(function (model) {
			return !filterModels.contains(model.get("id"))
		});

		if (searchModel.length > 0) {
			return listModels.filter(function (e) {
				return e.get('name').toUpperCase().indexOf(searchModel) > -1;
			});
		} else {
			return listModels;
		}
	}.property('listModels.content', 'searchModel', 'filterModels'),
	hasPercentileAccess: function () {
		return Utils.hasRead(this.get('session'), 'percentile');
	}.property("session"),
	hasSessionWrite: function () {
		return Utils.hasWrite(this.get('session'), 'session');
	}.property("session"),
	hasModelRead: function () {
		return Utils.hasRead(this.get('session'), 'model_session')
	}.property("session"),
	list: function () {
		var c = this.get('model');
		if (c == undefined) {
			return []
		}
		var ret = [];
		c.forEach(function (e) {
			ret.addObject(e)
		});
		return ret;
	}.property('model'),
	percentileManage: function () {

		var listSessions = this.get('list');
		listSessions.forEach(function (session) {
			session.set('has_made', session.get('completed_time') != null);
		});
		var _this = this;


		listSessions.forEach(function (session) {
			session.get('list_activities').then(function (activities) {
				var promise_percentile = session.get('percentile');
				if (promise_percentile != null) {
					promise_percentile.then(function (percentile) {
						if (percentile != null) {
							//console.log("Found: T:" + type_percentile + " c:" + group.get('schoolYear') + " t:" + trimester);
							if (percentile.getPercentile != undefined) {
								var velocity = session.get('sorted_list_activities.lastObject.words_minute_filtered');
								session.set('percentile_value', percentile.getPercentile(velocity))
							} else {
								session.set('percentile_value', -1);
							}
						} else {
							//console.log("Not found: T:" + type_percentile + " c:" + group.get('schoolYear') + " t:" + trimester);
							session.set('percentile_value', -2)
						}
					});
				} else {
					session.set('percentile_value', -3);
				}
			});
		});

		return listSessions;
	}.property('percentileList.content', 'studentGroup', 'list.@each'),
	graphAxisNames: function (session) {
		var day = moment(session.get('completed_time')).format('ll');
		return session.get('name') + " (" + day + ")";
	},
	drawGraph: function () {
		Ember.run.scheduleOnce('afterRender', {}, function () {
			var list = this.get('percentileManage').filter(function (session) {
				return session.get('completed_time') != null;
			}).sortBy('completed_time');
			var i18n = this.get('i18n');
			var graphAxisNames = this.graphAxisNames;
			var plot = this.get('sessionsPlot');
			if (plot != null) {
				plot.destroy();
				this.set('sessionsPlot', null);
			}
			if (list.length > 0) {
				var percentilesValues = list.filter(function (session) {
					var percentile_value = session.get('percentile_value');
					var p_valid = !Utils.isValidNumber(percentile_value) || percentile_value >= 0;
					return p_valid;
				}).map(function (session, index) {
					var p = session.get('percentile_value');
					if (p == ">100") {
						p = 105;
					} else if (p == "<0") {
						p = -5;
					}
					return [graphAxisNames(session), p];
				});
				var beginStatusList = list.map(function (session) {
					return [graphAxisNames(session), session.get('status_begin')];
				});
				var endStatusList = list.map(function (session) {
					return [graphAxisNames(session), session.get('status_end')];
				});
				var difficultyList = list.map(function (session) {
					return [graphAxisNames(session), session.get('difficulty')];
				});

				plot = $.jqplot('sessions_plot', [beginStatusList, endStatusList, difficultyList, percentilesValues], {
					series: [{
						yaxis: 'y2axis',
						label: i18n.t('session.graph.begin_status')
					}, {
						yaxis: 'y2axis',
						label: i18n.t('session.graph.end_status')
					}, {
						yaxis: 'y2axis',
						label: i18n.t('session.graph.difficulty')
					}, {
						label: i18n.t('session.graph.percentile')
					}],
					axesDefaults: {
						tickRenderer: $.jqplot.CanvasAxisTickRenderer,
						tickOptions: {
							angle: -30
						}
					},
					legend: {
						show: true,
						placement: 'inside',
						location: 'sw'

					},
					axes: {
						yaxis: {
							min: 0,
							max: 100,
							numberTicks: 11,
							label: i18n.t('session.graph.percentiles'),
							labelRenderer: $.jqplot.CanvasAxisLabelRenderer,
						},
						xaxis: {
							label: i18n.t('session.graph.session'),
							labelRenderer: $.jqplot.CanvasAxisLabelRenderer,
							renderer: $.jqplot.CategoryAxisRenderer,
							rendererOptions: {sortMergedLabels: false},
							tickOptions: {
								showGridline: false
							}
						},
						y2axis: {
							min: 0,
							max: 10,
							numberTicks: 11
						}
					}
				});
				this.set('sessionsPlot', plot);
			}
		}.bind(this));

	}.observes('percentileManage.@each.percentile_value'),
	actions: {
		didTransition: function () {
			var student = this.controllerFor('student');
			student.set('currentLink', 'sessions')
		},
		addList: function () {
			var size = this.get('pageSize');
			this.set('pageSize', size + 10);
		},
		goToSession: function (session) {
			this.transitionToRoute('session', session.id)
		},
		addFilter: function (model) {
			var list = this.get('filterModels');
			list.addObject(model.id);
		},
		removeFilter: function (model) {
			this.get('filterModels').removeObject(model.get('id'))
		},
		clearFilters: function () {
			this.set('filterModels', [])
		},
		showFilter: function () {
			var showingFilter = this.get('showingFilter');
			this.set('showingFilter', !showingFilter);
		},
		addSession: function (modelSession, dayToCreate) {
			console.log("sessions add session");
			if (modelSession != null) {
				var newSession = this.store.createRecord('session', {
					publish_date: dayToCreate,
					model_based: modelSession,
					student: this.get('controllers.student.model')
				});
				var promise = newSession.save();
				var _this = this;
				promise.then(function (session) {
					_this.get('list').insertAt(0, newSession);
				});
				return promise;
			} else {
				alert(this.get('i18n').t("student.errors.not-selected-model"));
			}
		},
		deleteSession: function (session) {
			if (confirm(this.get('i18n').t('session.confirm.delete'))) {
				var promise = session.destroyRecord();
				var _this = this;
				promise.then(function () {
					var list = _this.get('list');
					list.removeObject(session);
					if (session.get('id') == _this.get('sub_session_model.id')) {
						_this.transitionToRoute('sessions')
					}
				});

			}
		}
	},
	resetController: function (controller, isExiting, transition) {
		if (isExiting) {
			// isExiting would be false if only the route's model was changing
			controller.set('dayOffset', 0);
			controller.set('pageSize', 10);
		}
	}
});
