import Ember from 'ember';
import { translationMacro as t } from "ember-i18n";
import Utils from '../../utils/utils'

export default Ember.Controller.extend({
	needs: ["user_session", "language"],
	language_list:Ember.computed.alias("controllers.language.list"),
	i18n:Ember.inject.service(),

	firstNameLabel:t("student.first-name"),
	secondNameLabel:t("student.second-name"),
	thirdNameLabel:t("student.third-name"),
	birthdayLabel:t("student.birthday"),
	emailLabel:t("global.email"),
	schoolLabel:t("student.edit.school"),
	courseLabel:t("student.edit.course"),
	courseLineLabel:t("student.edit.course-line"),
	selectLanguagePrompt:t("global.lang.select"),
	selectMeetUsPrompt:t("student.edit.meet-us.prompt"),

	showSaveOk: false,

	session: Ember.computed.alias("controllers.user_session.session"),
	hasStudentReadOnly: function (){
		var session=this.get('session');
		var info= !Utils.hasWrite(session, 'student');
		return info;
	}.property('session'),
	list_difference_course: function (){
		var i18n=this.get('i18n');
		return [Utils.createElement(-2,i18n.t("student.difference-course.-2")),
			Utils.createElement(-1,i18n.t("student.difference-course.-1")),
			Utils.createElement(0, i18n.t("student.difference-course.0")),
			Utils.createElement(1,i18n.t("student.difference-course.1")),
			Utils.createElement(2,i18n.t("student.difference-course.2"))];
	}.property(),
	selected_course_difference: function (){
		var list=this.get('list_difference_course');
		var course=parseInt(this.get('model.course_difference'));
		return list.find(function (e){
			return e.id==course;
		});
	}.property('model.course_difference', 'list_difference_course'),
	idLanguage: function (){
		return this.get('model.language.id');
	}.property('model.language.id'),
	selected_language: function (){
		var language=this.get('model.language.id');
		if (language!=null){
			language = this.get('language_list').find(function (e){
				return e.get('id')==language;
			});
		} else {
			language= this.get('language_list.0');
		}
		return language;
	}.property('model.language', 'language_list.content'),//*/
	meet_us_list: function (){
		var i18n=this.get('i18n');
		return [
			Utils.createElement("known",i18n.t("student.edit.meet-us.known")),
			Utils.createElement("web",i18n.t("student.edit.meet-us.web")),
			Utils.createElement("radio",i18n.t("student.edit.meet-us.radio")),
			Utils.createElement("tv",i18n.t("student.edit.meet-us.tv")),
			Utils.createElement("press",i18n.t("student.edit.meet-us.press")),
			Utils.createElement("eap",i18n.t("student.edit.meet-us.eap")),
			Utils.createElement("school",i18n.t("student.edit.meet-us.school")),
			Utils.createElement("ub",i18n.t("student.edit.meet-us.ub")),
			Utils.createElement("association",i18n.t("student.edit.meet-us.association")),
			Utils.createElement("others",i18n.t("student.edit.meet-us.others"))
		];
	}.property(),
	where_meet_us: function (){
		var list=this.get('meet_us_list');
		var id_meet=this.get('model.where_meet_us');
		return list.find(function (e){
			return e.id==id_meet;
		})//*/
	}.property('model.where_meet_us', 'meet_us_list'),//*/
	checkDataAndSave: function (){
		var i18n=this.get('i18n');
		var model=this.get('model');
		var errors=[];
		if (model.get('firstName')==""){
			errors.addObject(i18n.t('global.errors.field-required',
					{"field-name":i18n.t('student.first-name')}))
		}
		if (model.get('secondName')==""){
			errors.addObject(i18n.t('global.errors.field-required',
					{"field-name":i18n.t('student.second-name')}))
		}
		if (model.get('group.id')==null){
			errors.addObject(i18n.t('global.errors.select-field-required',
					{"field-name":i18n.t('student.group')}));
		}
		if (errors.length>0){
			alert(i18n.t('global.errors.check-and-solve')+'\n'+errors.join("\n"));
		} else {
			var id=this.get('idLanguage');
			this.set('model.language', this.get('language_list').find(function (e){
				return e.id==id;
			}));
			var promise=this.get('model').save();
			promise.catch(function (e){
				Utils.handleGenericErrors(e);
			});
			return promise;
		}
		return false;
	},
	actions: {
		show_manage_users: function (){
			if (this.get('model.group.id')!=null){
				$('#selectUsersModal').modal('show');
			} else {
				alert(i18n.t('student.errors.select-group'));
			}
		},
		saveChanges: function () {
			var saveInfo=this.checkDataAndSave();
			var _this=this;
			saveInfo.then(function (){
				_this.set('showSaveOk', true);
			});
		},
		saveChangesAndGoSessions: function (){
			var saveInfo=this.checkDataAndSave();
			var _this=this;
			saveInfo.then(function (d){
				_this.transitionToRoute('sessions', d.get('id'));
			})
		},
		discardChanges: function (){
			this.get('model').rollback();
		},
		setGroup: function (group){
			this.get('model').set('group', group);
		}
	}
});
