import Ember from 'ember';
import Utils from 'Dashboard/utils/utils';

export default Ember.Controller.extend({
	i18n: Ember.inject.service(),
	cache: Ember.inject.service(),
	userSession : Ember.inject.controller(),
	hasSessionWrite: function (){
		var session=this.get('userSession.session');
		return Utils.hasWrite(session, 'session');
	}.property('userSession'),
	hasStudentReadOnly: function (){
		var session=this.get('userSession.session');
		return !Utils.hasWrite(session, 'student');
	}.property('userSession.session'),

	message: {
		show:false,
		timer: null,
		type: "",
		text: ""
	},

	selectWarningLevelPrompt: function(){
		return this.get('i18n').t('student.summary.select-level-prompt');
	}.property(),
	listLevels: Ember.computed.alias('cache.warningsLevels'),
	levelFilter: null,
	hasLevelSelected: function (){
		return this.get('levelFilter')!==null;
	}.property('levelFilter'),

	selectWarningPrompt: function(){
		return this.get('i18n').t('student.summary.select-warning-prompt');
	}.property(),
	listWarnings: function (){
		var level=parseInt(this.get('levelFilter.id'));
		return this.get('cache.warnings').filter(function (e){
			return e.get('level')===level;
		});
	}.property('levelFilter', 'cache.warnings'),
	warning: null,
	hasWarningNotSelected: function (){
		return this.get('warning')===null;
	}.property('warning'),

	warnings: function (){
		var ret=[];
		this.get('model.warnings').forEach(function (w){
			ret.push(w)
		});
		return ret;
	}.property('model.warnings'),

	actions: {
		add(){
			var warning=this.get('warning');
			var warning_list=this.get('warnings');
			if (!warning_list.contains(warning)){
				warning_list.pushObject(warning)
			}
			this.set('warning', null);
		},
		discard(){
			var model=this.get('model');
			model.rollbackAttributes();
			this.set('warnings', model.get('warnings'));
		},
		save(){
			var model=this.get('model');
			var model_warnings=model.get('warnings');
			var warnings = this.get('warnings');
			model_warnings.clear();
			warnings.forEach(function (w){
				model_warnings.pushObject(w);
			});
			var i18n=this.get('i18n');
			model.save().then(function (){
				this.set('message', {
					show:true,
					type:"info",
					timer:15,
					text: i18n.t('global.messages.save-ok')
				});
			}.bind(this), function (){
				this.set('message', {
					show:true,
					type:"error",
					text: i18n.t('student.messages.update-err')
				});
			}.bind(this));
		},
		removeWarning(warning){
			var warnings=this.get('warnings');
			warnings.removeObject(warning);
		}
	}

});
