import DS from 'ember-data';

export default DS.Model.extend({
	session : DS.belongsTo('session'),
	sort : DS.attr('number'),
	type : DS.attr('number'),
	game: DS.belongsTo('game', {async:true}),
	group: DS.attr('string'),
	title: DS.attr('string'),
	instructions: DS.attr('string'),
	words: DS.attr('string'),
	clock: DS.attr('number'),
	counters: DS.attr('number'),
	sequence_length: DS.attr('number'),
	difficult_level: DS.attr('number'),
	repeat: DS.attr('number'),
	shuffle: DS.attr('boolean'),
	transition: DS.attr('number'),
	success: DS.attr('number'),
	mistakes: DS.attr('number'),
	time_game: DS.attr('number'),
	words_minute : DS.attr('number'),
	name: DS.attr('string'),
	results: DS.attr('string'),
	times : DS.attr('string'),
	results_before_mistakes: DS.attr('string'),
	help_first_level: DS.attr('number'),
	help_second_level: DS.attr('number'),
	space_letters: DS.attr('number'),
	spaced_times: function (){
		var times=this.get('times');
		if (times){
			return times.replace(/,/g,', ');
		}
		return "";
	}.property('times'),

	words_minute_filtered: function (){
		function mean(list){
			return list.reduce(function (e, ac){ return e+ac;}, 0.0)/list.length;
		}
		function stdev(list, avg){
			if (!avg){
				avg=mean(list);
			}
			var acum=list.reduce(function (ac,e){
				return Math.pow(e-avg,2)+ac;
			}, 0.0);
			return Math.sqrt(acum/list.length);
		}
		const n=1.5;
		var times=this.get('times');
		if (times && times.length>0){
			times=times.split(",").map(function (e){ return parseInt(e);});
			var avg = mean(times);
			var dev = stdev(times, avg);
			times = times.filter(function (e){
				return Math.abs(e-avg)<=n*dev;
			});
			return 60*1000/mean(times);
		} else {
			return this.get('words_minute');
		}
	}.property('times')
});
