import DS from 'ember-data';
import Utils from '../utils/utils'

export default DS.Model.extend({
	firstName: DS.attr("string"),
	secondName: DS.attr("string"),
	thirdName: DS.attr("string"),
	group: DS.belongsTo("group", {async:true}),
	user_manager: DS.hasMany('user', {async:true}),
	birthday: DS.attr("date"),
	tag: DS.attr("string"),
	email: DS.attr("string"),
	course_difference: DS.attr("number"),
	observation: DS.attr("string"),
	session_observation: DS.attr("string"),
	school_text: DS.attr("string"),
	course_text: DS.attr("string"),
	course_line_text: DS.attr('string'),
	language: DS.belongsTo("language", {async: true}),
	where_meet_us: DS.attr('string'),
	patternConfigs: DS.hasMany('older-pattern-relation', {async:true}),
	warnings: DS.hasMany('warnings', {async:true}),
	lastName :function (){
		return this.get('secondName')+" "+this.get('thirdName');
	}.property("secondName", "thirdName"),
	allPatternsWarning: function (){
		var ret=[];
		var configs=this.get('patternConfigs');
		if (configs){
			configs.forEach(function (c){
				var warnings=c.get('warnings');
				if (warnings){
					warnings.forEach(function (w){
						if (!ret.contains(w)){
							ret.push(w);
						}
					});
				}
			});
		}

		return ret.sort(function (e1, e2){
			return e1.get('level')-e2.get('level');
		});
	}.property('patternConfigs.@each.warnings.[]'),
	isBirthdayAvailable: function (){
		return Utils.isValidDate(this.get('birthday'));
	}.property('birthday'),
	course: function () {
		return this.calculateCourse();
	}.property('group', 'birthday'),
	calculateCourse: function (reference){
		var birthday=this.get('birthday');
		if (Utils.isValidDate(birthday) && birthday.getYear()!=0){
			var _this=this;
			if (reference!==undefined || !Utils.isValidDate(reference)){
				reference=new Date();
			}
			var age=reference.getYear()-birthday.getYear();
			if (reference.getMonth()<8){
				age--;
			}

			//console.log("age:"+age);
			age=age+this.get('course_difference');
			//console.log("Rectified age"+age);

			var promise= new Ember.RSVP.Promise(function (resolver, reject){
				var p=_this.store.query('course', {});
				p.then(function (list){
					//console.log("list_courses:");
					//console.log(list);
					var course=list.find(function (e){
						//console.log(e.get('age')+"vs"+age);
						return e.get('age')==age;
					});
					if (course!==undefined){
						//console.log("Course:"+course.get('name'));
						resolver(course);
						return course;
					} else {
						resolver(null);
					}
				}, reject);
			});
			return DS.PromiseObject.create({promise: promise });
		} else {
			var course=this.get('group.course');
			return this.get('group.course');
		}
	}
});
