import { moduleFor, test } from 'ember-qunit';
import Ember from 'ember';

moduleFor('controller:page', {
	// Specify the other units that are required for this test.
	// needs: ['controller:foo']
});


test('check is First page', function (assert) {
	//expect(2);
	var ctrl = this.subject();

	ctrl.set('page', 0);
	assert.ok(ctrl.get('isFirst'));

	ctrl.set('page', 2);
	assert.ok(!ctrl.get('isFirst'));
});

test('check number of pages', function (assert) {
	var ctrl = this.subject();
	var mockData = [];
	mockData.meta = {total: 1};

	ctrl.set('model', mockData);
	ctrl.set('pageSize', 10);
	assert.equal(ctrl.get('numPages'), 1);

	ctrl.set('totalItems', 10);
	assert.equal(ctrl.get('numPages'), 1);

	ctrl.set('totalItems', 11);
	assert.equal(ctrl.get('numPages'), 2);

	ctrl.set('pageSize', 20);
	assert.equal(ctrl.get('numPages'), 1);
});

test('check is Last page', function (assert) {
	//expect(5);
	var ctrl = this.subject();
	var mockData = [];
	mockData.meta = {total: 1};
	ctrl.set('model', mockData);

	ctrl.set('page', 0);
	ctrl.set('pageSize', 10);
	ctrl.set('totalItems', 1);
	assert.ok(ctrl.get('isLast'));

	ctrl.set('totalItems', 9);
	assert.ok(ctrl.get('isLast'));

	ctrl.set('totalItems', 10);
	assert.ok(ctrl.get('isLast'));

	ctrl.set('totalItems', 11);
	assert.ok(!ctrl.get('isLast'));

	ctrl.set('page', 1);
	assert.ok(ctrl.get('isLast'));
});

test('check the list of near pages', function (assert) {
	var ctrl = this.subject();
	var mockData = [];
	mockData.meta = {total: 1};
	ctrl.set('model', mockData);
	ctrl.set('pageSize', 10);

	var createExpect = function (name, current) {
		return {label: name, id: name - 1, current: current};
	};

	var expected = [createExpect(1, true)];
	assert.deepEqual(ctrl.listNearPages(3), expected);

	ctrl.set('totalItems', 40);
	expected = [createExpect(1, true), createExpect(2, false), createExpect(3, false), createExpect(4, false)];
	assert.deepEqual(ctrl.listNearPages(3), expected);

	ctrl.set('totalItems', 80);
	expected = [createExpect(1, true), createExpect(2, false), createExpect(3, false), createExpect(4, false)];
	assert.deepEqual(ctrl.listNearPages(3), expected);

	ctrl.set('page', 6);
	expected = [createExpect(4, false), createExpect(5, false), createExpect(6, false), createExpect(7, true), createExpect(8, false)];
	assert.deepEqual(ctrl.listNearPages(3), expected);

	ctrl.set('totalItems', 170);
	expected = [createExpect(4, false), createExpect(5, false), createExpect(6, false),
		createExpect(7, true),
		createExpect(8, false), createExpect(9, false), createExpect(10, false)];
	assert.deepEqual(ctrl.listNearPages(3), expected);
});

test('check transition query params', function (assert) {
	//expect(1);
	var ctrl = this.subject();

	ctrl.set('page', 1);
	assert.deepEqual(ctrl.getTransitionQueryParams(+1), {queryParams: {page: 2}});
});