import Utils from 'Dashboard/utils/utils';
import { module, test } from 'qunit';
import moment from 'moment';

module('Unit | Utility | utils');

test("Ensure promise", function (assert){
  var data={};
  var promise=Utils.ensurePromise(data);
  assert.notEqual(promise.then,undefined);
  assert.notEqual(promise.fail,undefined);
});

test("Compare Format Day", function (assert){
  var day=new Date();
  day.setDate(1);
  day.setMonth(11);
  day.setYear(2015);
  var compareDay="1-11-2015";
  assert.equal(Utils.compareFormatDay(day), compareDay);

  compareDay="10-1-2010";
  day.setMonth(1,10);
  day.setYear(2010);
  assert.equal(Utils.compareFormatDay(day), compareDay);
});

test("Compare Database Format Day", function (assert){
  var day=new Date();
  day.setMonth(2,1);
  day.setYear(2001);
  var compareDay="2001-3-1";
  assert.equal(Utils.dbFormatDay(day), compareDay);

  day.setMonth(10,12);
  day.setYear(2010);
  compareDay="2010-11-12";
  assert.equal(Utils.dbFormatDay(day), compareDay);
});

test("Check has read permissions", function (assert){
  var mockSession={
    value:"",
    get: function (assert){
      return this.value;
    }
  };
  assert.ok(!Utils.hasRead(mockSession, ""));
  mockSession.value="read";
  assert.ok(Utils.hasRead(mockSession, ""));
  mockSession.value="write";
  assert.ok(Utils.hasRead(mockSession, ""));
});

test("Check has write permissions", function (assert){
  var mockSession={
    value:"",
    get: function (assert){
      return this.value;
    }
  };
  assert.ok(!Utils.hasWrite(mockSession, ""));
  mockSession.value="read";
  assert.ok(!Utils.hasWrite(mockSession, ""));
  mockSession.value="write";
  assert.ok(Utils.hasRead(mockSession, ""));
});

test("Check is Valid date function", function (assert){
  assert.expect(4);

  var d={};
  assert.equal(Utils.isValidDate(d), false);

  d=null;
  assert.equal(Utils.isValidDate(d), false);

  d=new Date("Erroni????");
  assert.equal(Utils.isValidDate(d), false);

  d=new Date();
  assert.equal(Utils.isValidDate(d), true);
});

test ("Check get trimestre function", function (assert){
  assert.expect(6);

  var d=moment("20150901", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 1);

  d=moment("20151231", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 1);

  d=moment("20150101", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 2);

  d=moment("20150331", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 2);

  d=moment("20150401", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 3);

  d=moment("20150831", "YYYYMMDD").toDate();
  assert.equal(Utils.trimester(d), 3);

});